@@ -1,10 +1,12 @@
+use std::collections::HashMap;
+use std::convert::From;
 use std::fmt;
 use std::ops::Deref;
-use std::convert::From;
-use std::collections::HashMap;
 
-use rocket_dyn_templates::Template;
+use printnanny_services::config::PrintNannyConfig;
 use rocket::response::{Flash, Redirect};
+use rocket::serde::json::Json;
+use rocket_dyn_templates::Template;
 use thiserror::Error;
 
 use crate::error;
@@ -33,7 +35,7 @@ impl From<serde_json::Error> for FlashResponse<Redirect> {
         context.insert("errors", &msg);
         error!("{}", &msg);
         Self(Flash::error(Redirect::to("/"), &msg))
-    }  
+    }
 }
 
 // impl From<printnanny_services::printnanny_api::ServiceError> for FlashResponse<Redirect> {
@@ -84,6 +86,7 @@ impl<R> From<Flash<R>> for FlashResponse<R> {
 
 #[derive(Debug, Responder)]
 pub enum Response {
+    PrintNannyConfig(Json<PrintNannyConfig>),
     Template(Template),
     Redirect(Redirect),
-}
\ No newline at end of file
+}
